@@ -1,4 +1,4 @@
-#' Total Drainage Area
+#' DEPRECATED: Total Drainage Area
 #' @description Calculates total drainage area given a dendritic
 #' network and incremental areas.
 #' @param x data.frame with ID, toID, and area columns.
@@ -25,11 +25,13 @@
 
 calculate_total_drainage_area <- function(x) {
 
+  warning("calculate_total_drainage_area() is deprecated. Please switch to hydroloom equivalent.")
+
   return(accumulate_downstream(x, "area"))
 
 }
 
-#' Calculate Arbolate Sum
+#' DEPRECATED: Calculate Arbolate Sum
 #' @description Calculates arbolate sum given a dendritic
 #' network and incremental lengths. Arbolate sum is the total length
 #' of all upstream flowlines.
@@ -55,6 +57,8 @@ calculate_total_drainage_area <- function(x) {
 
 calculate_arbolate_sum <- function(x) {
 
+  warning("calculate_arbolate_sum is deprecated. Please switch to hydroloom equivalent.")
+
   return(accumulate_downstream(x, "length"))
 
 }
